# lwjs
**LightWeight JSON Shell** is a package to allow simple inline like-in-bash-shell expressions in your JSON documents. Technically, no limits exist to apply on Python objects as well.

# moar
Visit project [homepage](https://github.com/andreihes/lwjs) for more documentation and examples.